@@ -443,6 +443,7 @@ def calculate_CALI_BS(df: pd.DataFrame) -> pd.DataFrame:
     if "CALI" in df.columns:
         if "BS" not in df.columns:
             df = guess_BS_from_CALI(df)
+        print(df.dtypes)
         df["CALI-BS"] = df["CALI"] - df["BS"]
     else:
         raise ValueError(
@@ -761,7 +762,7 @@ def calculate_VSH(df: pd.DataFrame, **kwargs) -> pd.DataFrame:
         df["GR_ss"] = df["Age"].map(df.groupby("Age")["GR"].quantile(quant_ss))
 
         # Calculate GR_sh_Gp_f
-        for group_name, group_series in df.groupby(fg_col)["GR"]:
+        for group_name, group_series in df.groupby(fg_col, dropna=False)["GR"]:
             # First calculate the quantiles
             rolling_quantiles = group_series.rolling(
                 min(rolling_window_size, group_series.size // 2), center=True
