@@ -1,10 +1,10 @@
+from akerbp.mlpet.tests.data.data import TEST_DF
 from akerbp.mlpet.Datasets.imputers import (
+    simple_impute,
+    iterative_impute,
     generate_imputation_models,
     impute_depth_trend,
-    iterative_impute,
-    simple_impute,
 )
-from akerbp.mlpet.tests.data.data import TEST_DF
 
 
 def test_simple_impute():
@@ -22,6 +22,8 @@ def test_impute_depth_trend():
         TEST_DF[["DEPTH", "AC", "BS"]],
         curves_to_impute=["BS"],
         depth_column="DEPTH",
+        save_imputation_models=True,
+        folder_path="./",
     )
     assert not df.isnull().any().any()
 
@@ -35,5 +37,7 @@ def test_impute_depth_trend_with_provided_models():
         curves_to_impute=["BS"],
         imputation_models=models,
         depth_column="DEPTH",
+        save_imputation_models=True,
+        folder_path="./",
     )
     assert not df.isnull().any().any()
