@@ -1,11 +1,11 @@
-import yaml
 from cognite.client import CogniteClient
+import yaml
 
 from akerbp.mlpet import utilities as utils
 from akerbp.mlpet.tests.data.data import (
     FORMATION_TOPS_MAPPER,
-    TEST_DF,
     VERTICAL_DEPTHS_MAPPER,
+    TEST_DF,
 )
 
 CLIENT = CogniteClient(
@@ -33,10 +33,9 @@ def test_remove_wo_label():
 
 def test_standardize_names():
     mapper = yaml.load(
-        open("src/akerbp/mlpet/tests/data/test_mappings.yaml", "r"),
-        Loader=yaml.SafeLoader,
+        open("akerbp/mlpet/tests/data/test_mappings.yaml", "r"), Loader=yaml.SafeLoader
     )
-    utils.standardize_names(TEST_DF.columns.tolist(), mapper=mapper)
+    names = utils.standardize_names(TEST_DF.columns.tolist(), mapper=mapper)
 
 
 def test_standardize_group_formation_name():
